/*
 * Created on Mar 4, 2006
 *
 */
package javaMIDISoundServer;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.ConnectException;
import java.net.Socket;
import java.net.SocketException;

/**
 * @author dstulken
 *
 * JaMISS_Client2.java - Java MIDI Sound Server Test Client for ISU HCI research
 * (c) 2006 David Stulken, Iowa State University
 *  
 * First command line argument = host to connect to   (ex: localhost or ip in form xxx.yyy.zzz.www)
 * Second command line argument = port to use           (ex: 8006)
 * 
 */
public class JaMISS_Client2 {

	/*
	 	JaMISS Client
	 	
		Sends the message specified on the command line.
	 */
	
	
	public static void main(String[] args){

		//print usage:
		System.out.println("Test Client starting.  Usage: JaMISS_Client [host IP] [host port] [message]\n\n");
		
		//parse input arguments
		String host=args[0];
		int port=Integer.parseInt(args[1]);
		
		//print "welcome" message
		System.out.println("*** JaMISS Client has been started ***");

		
		
		//****************************************************************************************************************
		//First test message
		//****************************************************************************************************************
		
		//start the client  
			try {
	    
				//create client socket connection to the computer specified by the
				//second program argument, at the port specified by the first argument
				Socket socketB = new Socket(host, port);
	    	
				//create input stream for receiving data from server
				BufferedReader inputB = new BufferedReader(new InputStreamReader(socketB.getInputStream()));
	    	
				//create output stream for sending data to server
				//   note: set to auto-flush.  Not sure if necessary, but I see no reason why it would hurt.
				PrintWriter outputB = new PrintWriter(socketB.getOutputStream(), true);
	    	
				//send data to server
				outputB.println(args[2]); //send data
					    	
				//receive data from server
				System.out.println(inputB.readLine());
	    	
				//done, so close everything (backwards order from creation!)
				outputB.close();	//close PrintWriter 
				socketB.close();	//close socket
	    	
			}//end of try
			catch(ConnectException c){
				//server not yet ready!
				//"fix" this by decrementing x by 1, so it "retries"
				//do not print notice of exception, we want this to be transparent.
				
				System.err.println(c);
			}
			catch (SocketException s){
				//connection reset!
				//"fix" this by decrementing x by 1, so it "retries"
				//do not print notice of exception, we want this to be transparent.
				
				System.err.println(s);
			}
			catch(Exception e) {
				//print generic error message (this would be an unknown exception,
				// so we want to know what went wrong)
				System.out.println("CLIENT: *** EXCEPTION! ***");
				System.err.println(e);
			}

			
		//print "goodbye" message
		System.out.println("*** Client Finished ***");

	}//end of main
}//end of class
